<!-- markdownlint-disable -->

<a href="..\..\qtstrap\widgets\layouts.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `widgets.layouts`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**
- **alignments**
- **orientations**


---

<a href="..\..\qtstrap\widgets\layouts.py#L23"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `ContextLayout`




<a href="..\..\qtstrap\widgets\layouts.py#L24"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ContextLayout.__init__`

```python
__init__(parent=None, stretch=None, margins=None, align=None, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\layouts.py#L68"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ContextLayout.add`

```python
add(item, *args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L87"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ContextLayout.grid`

```python
grid(*args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L83"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ContextLayout.hbox`

```python
hbox(*args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L98"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ContextLayout.scroll`

```python
scroll(name=None, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L91"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ContextLayout.split`

```python
split(name=None, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L79"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ContextLayout.vbox`

```python
vbox(*args, **kwargs)
```






---

<a href="..\..\qtstrap\widgets\layouts.py#L121"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `CVBoxLayout`




<a href="..\..\qtstrap\widgets\layouts.py#L24"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CVBoxLayout.__init__`

```python
__init__(parent=None, stretch=None, margins=None, align=None, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\layouts.py#L68"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CVBoxLayout.add`

```python
add(item, *args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L87"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CVBoxLayout.grid`

```python
grid(*args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L83"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CVBoxLayout.hbox`

```python
hbox(*args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L98"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CVBoxLayout.scroll`

```python
scroll(name=None, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L91"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CVBoxLayout.split`

```python
split(name=None, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L79"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CVBoxLayout.vbox`

```python
vbox(*args, **kwargs)
```






---

<a href="..\..\qtstrap\widgets\layouts.py#L125"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `CHBoxLayout`




<a href="..\..\qtstrap\widgets\layouts.py#L24"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CHBoxLayout.__init__`

```python
__init__(parent=None, stretch=None, margins=None, align=None, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\layouts.py#L68"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CHBoxLayout.add`

```python
add(item, *args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L87"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CHBoxLayout.grid`

```python
grid(*args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L83"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CHBoxLayout.hbox`

```python
hbox(*args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L98"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CHBoxLayout.scroll`

```python
scroll(name=None, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L91"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CHBoxLayout.split`

```python
split(name=None, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L79"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CHBoxLayout.vbox`

```python
vbox(*args, **kwargs)
```






---

<a href="..\..\qtstrap\widgets\layouts.py#L129"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `CGridLayout`




<a href="..\..\qtstrap\widgets\layouts.py#L24"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CGridLayout.__init__`

```python
__init__(parent=None, stretch=None, margins=None, align=None, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\layouts.py#L68"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CGridLayout.add`

```python
add(item, *args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L87"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CGridLayout.grid`

```python
grid(*args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L83"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CGridLayout.hbox`

```python
hbox(*args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L98"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CGridLayout.scroll`

```python
scroll(name=None, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L91"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CGridLayout.split`

```python
split(name=None, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L79"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CGridLayout.vbox`

```python
vbox(*args, **kwargs)
```






---

<a href="..\..\qtstrap\widgets\layouts.py#L136"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `CSplitter`




<a href="..\..\qtstrap\widgets\layouts.py#L137"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CSplitter.__init__`

```python
__init__(parent=None, margins=None, orientation=None, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\layouts.py#L151"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CSplitter.add`

```python
add(item, stretch=None)
```






---

<a href="..\..\qtstrap\widgets\layouts.py#L172"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `PersistentCSplitter`




<a href="..\..\qtstrap\widgets\layouts.py#L173"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentCSplitter.__init__`

```python
__init__(name, parent=None, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\layouts.py#L151"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentCSplitter.add`

```python
add(item, stretch=None)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L179"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentCSplitter.restore_state`

```python
restore_state()
```






---

<a href="..\..\qtstrap\widgets\layouts.py#L190"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `CScrollArea`




<a href="..\..\qtstrap\widgets\layouts.py#L191"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CScrollArea.__init__`

```python
__init__(parent=None, margins=None, orientation=None, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\layouts.py#L213"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CScrollArea.add`

```python
add(item, stretch=None)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L230"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CScrollArea.addLayout`

```python
addLayout(*args, **kwargs)
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L227"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CScrollArea.addWidget`

```python
addWidget(*args, **kwargs)
```






---

<a href="..\..\qtstrap\widgets\layouts.py#L240"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `PersistentCScrollArea`




<a href="..\..\qtstrap\widgets\layouts.py#L241"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentCScrollArea.__init__`

```python
__init__(name, parent=None, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\layouts.py#L251"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentCScrollArea.restore_state`

```python
restore_state()
```





---

<a href="..\..\qtstrap\widgets\layouts.py#L248"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentCScrollArea.scroll_to`

```python
scroll_to(value)
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
